@@ -757,6 +757,7 @@ class AsyncClient(BaseClient):
 
         client_order_id，24小时有效，超过24小时的订单根据client_order_id将查询不到
         """
+        assert symbol is not None
         data = package_data(remove_key(locals()))
         return await self._request_future_private_api("post", "contract_cancel", data=data)
 
@@ -1114,6 +1115,7 @@ class AsyncClient(BaseClient):
         撤单接口返回结果只代表撤单命令发送成功，建议根据订单查询接口查询订单的状态来确定订单是否已真正撤销。
         client_order_id，8 小时有效，超过 8 小时的订单根据client_order_id将查询不到。
         """
+        assert contract_code is not None
         data = package_data(remove_key(locals()))
         return await self._request_coin_margined_private_api("post", "swap_cancel", data=data)
 
@@ -1215,11 +1217,11 @@ class AsyncClient(BaseClient):
         return await self._request_coin_margined_private_api("post", "swap_lightning_close_position", data=data)
 
     #### U本位永续合约交易接口 #####
-
     async def usd_margined_cancel_order(self, contract_code, order_id=None, client_order_id=None, cross=True):
         """
         【全仓】撤销订单
         """
+        assert contract_code is not None
         data = package_data(remove_key(locals(), "self,cross"))
         return await self._request_usd_margined_private_api(
             "post", "swap_cross_cancel" if cross else "swap_cancel", data=data
